@@ -167,7 +167,7 @@ MODEL_CONFIGS = [
     ModelConfig(
         short_name="RPG",
         config_path="configs/stable-diffusion-v1.yaml",
-        weights_url="https://huggingface.co/Anashel/rpg/blob/main/RPG-V4-Model-Download/RPG-v4.safetensors",
+        weights_url="https://huggingface.co/Anashel/rpg/blob/resolve/RPG-V4-Model-Download/RPG-v4.safetensors",
         default_image_size=512,
         alias="rpg"
     ),
